(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     12021,        409]
NotebookOptionsPosition[     10394,        350]
NotebookOutlinePosition[     10751,        366]
CellTagsIndexPosition[     10708,        363]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Write out differential equation", "Text",
 CellChangeTimes->{{3.695986133242238*^9, 3.695986137009156*^9}}],

Cell[BoxData[
 RowBox[{"eq", ":=", 
  RowBox[{
   RowBox[{"DD", "*", 
    RowBox[{
     RowBox[{"C", "''"}], "[", "z", "]"}]}], "\[Equal]", 
   RowBox[{"beta", "*", 
    RowBox[{"Exp", "[", 
     RowBox[{
      RowBox[{"-", "lambda"}], "*", "z"}], "]"}], "*", 
    RowBox[{"C", "[", "z", "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.6959846201315813`*^9, 3.6959846422501383`*^9}, {
   3.695986085226678*^9, 3.695986089547971*^9}, 3.695986126896208*^9, 
   3.695986781583111*^9}],

Cell["\<\

Define the known parameters that we have\
\>", "Text",
 CellChangeTimes->{{3.695986146549961*^9, 3.6959861569892683`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"C0", ":=", "1"}], ";", 
  RowBox[{"beta", ":=", "3"}], ";", 
  RowBox[{"lambda", ":=", "20"}], ";", 
  RowBox[{"DD", ":=", "0.1"}], ";", 
  RowBox[{"H", ":=", "0.1"}], ";"}]], "Input",
 CellChangeTimes->{{3.695984649309102*^9, 3.695984649416233*^9}, {
   3.695985860755425*^9, 3.695985868505041*^9}, 3.695986140036131*^9, 
   3.6959867836643267`*^9}],

Cell["\<\

Check our equation still makese sense and is correct\
\>", "Text",
 CellChangeTimes->{{3.695986189245412*^9, 3.695986191246451*^9}}],

Cell[CellGroupData[{

Cell[BoxData["eq"], "Input",
 CellChangeTimes->{{3.69598465276433*^9, 3.695984687779154*^9}, {
  3.695985835633206*^9, 3.6959858413960867`*^9}, {3.695985872509996*^9, 
  3.695985881636632*^9}, {3.695986183067656*^9, 3.695986193566028*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"0.1`", " ", 
   RowBox[{
    SuperscriptBox["C", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "z", "]"}]}], "\[Equal]", 
  RowBox[{"3", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "20"}], " ", "z"}]], " ", 
   RowBox[{"C", "[", "z", "]"}]}]}]], "Output",
 CellChangeTimes->{3.69598683633027*^9}]
}, Open  ]],

Cell["\<\

Solve the differential equation subject to the correct boundary conditions\
\>", "Text",
 CellChangeTimes->{{3.6959862160637712`*^9, 3.69598622967721*^9}, {
  3.695986785945279*^9, 3.6959867891291227`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DSolve", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"eq", ",", 
     RowBox[{
      RowBox[{"C", "[", "H", "]"}], "\[Equal]", "C0"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"C", "'"}], "[", "0", "]"}], "\[Equal]", "0"}]}], "}"}], ",", 
   "C", ",", "z"}], "]"}]], "Input",
 CellChangeTimes->{{3.6959862337995243`*^9, 3.6959862338001966`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"C", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", "z", "}"}], ",", 
      RowBox[{
       RowBox[{"0.7422021303689332`", " ", 
        RowBox[{"BesselI", "[", 
         RowBox[{"0", ",", 
          RowBox[{"0.5477225575051661`", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "10.`"}], " ", "z"}]]}]}], "]"}]}], "+", 
       RowBox[{"0.1433587120692784`", " ", 
        RowBox[{"BesselK", "[", 
         RowBox[{"0", ",", 
          RowBox[{"0.5477225575051661`", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "10.`"}], " ", "z"}]]}]}], "]"}]}]}]}], "]"}]}], 
   "}"}], "}"}]], "Output",
 CellChangeTimes->{3.695986235455489*^9, 3.695986839493657*^9}]
}, Open  ]],

Cell["\<\

With this concentration profile we can now calculate the reaction rate \
r=beta*Exp[-lambda*z]*C\
\>", "Text",
 CellChangeTimes->{{3.6959862504552383`*^9, 3.695986277015978*^9}, 
   3.695986793482726*^9}],

Cell[BoxData[
 RowBox[{"r", ":=", 
  RowBox[{"beta", "*", 
   RowBox[{"Exp", "[", 
    RowBox[{
     RowBox[{"-", "lambda"}], "*", "z"}], "]"}], "*", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"0.7422021303689332`", " ", 
      RowBox[{"BesselI", "[", 
       RowBox[{"0", ",", 
        RowBox[{"0.5477225575051661`", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "10.`"}], " ", "z"}]]}]}], "]"}]}], "+", 
     RowBox[{"0.1433587120692784`", " ", 
      RowBox[{"BesselK", "[", 
       RowBox[{"0", ",", 
        RowBox[{"0.5477225575051661`", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "10.`"}], " ", "z"}]]}]}], "]"}]}]}], 
    "}"}]}]}]], "Input"],

Cell["\<\

Verify and simplify this expression\
\>", "Text",
 CellChangeTimes->{{3.695986296659285*^9, 3.695986304994981*^9}, 
   3.695986800682912*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", "r", "]"}]], "Input",
 CellChangeTimes->{{3.69598615981295*^9, 3.695986159820159*^9}, {
  3.6959861988081293`*^9, 3.6959862028132687`*^9}, {3.695986309890526*^9, 
  3.6959863424922256`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "20"}], " ", "z"}]], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2.2266063911067997`", " ", 
      RowBox[{"BesselI", "[", 
       RowBox[{"0", ",", 
        RowBox[{"0.5477225575051661`", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "10.`"}], " ", "z"}]]}]}], "]"}]}], "+", 
     RowBox[{"0.4300761362078352`", " ", 
      RowBox[{"BesselK", "[", 
       RowBox[{"0", ",", 
        RowBox[{"0.5477225575051661`", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{"-", "10.`"}], " ", "z"}]]}]}], "]"}]}]}], ")"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.6959863152571173`*^9, 3.6959863432966137`*^9}, 
   3.695986844304476*^9}]
}, Open  ]],

Cell["\<\

Now Integrate this over the depth of the stream\
\>", "Text",
 CellChangeTimes->{{3.695986351357469*^9, 3.6959863587812147`*^9}, 
   3.695986802392805*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Integrate", "[", 
  RowBox[{"r", ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "0", ",", "0.1"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubsuperscriptBox["\[Integral]", "0", "0.1`"], 
   RowBox[{
    RowBox[{"3", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "20"}], " ", "z"}]], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"0.7422021303689332`", " ", 
        RowBox[{"BesselI", "[", 
         RowBox[{"0", ",", 
          RowBox[{"0.5477225575051661`", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "10.`"}], " ", "z"}]]}]}], "]"}]}], "+", 
       RowBox[{"0.1433587120692784`", " ", 
        RowBox[{"BesselK", "[", 
         RowBox[{"0", ",", 
          RowBox[{"0.5477225575051661`", " ", 
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "10.`"}], " ", "z"}]]}]}], "]"}]}]}], ")"}]}], 
    RowBox[{"\[DifferentialD]", "z"}]}]}], "}"}]], "Output",
 CellChangeTimes->{3.695986367892263*^9, 3.695986848143517*^9}]
}, Open  ]],

Cell["\<\

Since nothing emerges - do a numerical integration. The above expression is \
to complicated to integrate analytically.\
\>", "Text",
 CellChangeTimes->{{3.695986372507107*^9, 3.695986392430193*^9}, 
   3.695986808389402*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NIntegrate", "[", 
  RowBox[{"r", ",", 
   RowBox[{"{", 
    RowBox[{"z", ",", "0", ",", "0.1"}], "}"}]}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", "0.12171663947313936`", "}"}]], "Output",
 CellChangeTimes->{3.695986401807205*^9, 3.695986851233953*^9}]
}, Open  ]],

Cell["\<\
This number is remarkably close to the zeroth order approximation - How come?




\
\>", "Text",
 CellChangeTimes->{{3.695986878286419*^9, 3.6959868948118258`*^9}}],

Cell[BoxData[
 RowBox[{"Conc", ":=", 
  RowBox[{
   RowBox[{"0.7422021303689332`", " ", 
    RowBox[{"BesselI", "[", 
     RowBox[{"0", ",", 
      RowBox[{"0.5477225575051661`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "10.`"}], " ", "z"}]]}]}], "]"}]}], "+", 
   RowBox[{"0.1433587120692784`", " ", 
    RowBox[{"BesselK", "[", 
     RowBox[{"0", ",", 
      RowBox[{"0.5477225575051661`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "10.`"}], " ", "z"}]]}]}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.695986723867601*^9, 3.695986744163165*^9}}],

Cell[CellGroupData[{

Cell[BoxData["Conc"], "Input",
 CellChangeTimes->{{3.695986747012512*^9, 3.695986747605446*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"0.7422021303689332`", " ", 
   RowBox[{"BesselI", "[", 
    RowBox[{"0", ",", 
     RowBox[{"0.5477225575051661`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "10.`"}], " ", "z"}]]}]}], "]"}]}], "+", 
  RowBox[{"0.1433587120692784`", " ", 
   RowBox[{"BesselK", "[", 
    RowBox[{"0", ",", 
     RowBox[{"0.5477225575051661`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "10.`"}], " ", "z"}]]}]}], "]"}]}]}]], "Output",
 CellChangeTimes->{3.695986748037566*^9, 3.69598685592318*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"z", ":=", "0"}], ";", "Conc"}]], "Input",
 CellChangeTimes->{{3.695986749668838*^9, 3.695986754377883*^9}}],

Cell[BoxData["0.920761862476955`"], "Output",
 CellChangeTimes->{3.6959867562025957`*^9, 3.695986858134221*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"z", "=", "0.1"}], ";", "Conc"}]], "Input",
 CellChangeTimes->{{3.69598675911979*^9, 3.695986763670746*^9}}],

Cell[BoxData["1.`"], "Output",
 CellChangeTimes->{3.6959867649368153`*^9, 3.69598685973422*^9}]
}, Open  ]],

Cell["\<\
Concentration varies not all that much with depth (less than 10%)  - hence \
reaction is comparable (within 10%)\
\>", "Text",
 CellChangeTimes->{{3.695986921283907*^9, 3.695986970322145*^9}}]
},
WindowSize->{808, 858},
WindowMargins->{{Automatic, 554}, {Automatic, 9}},
FrontEndVersion->"10.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (December 4, \
2014)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 113, 1, 30, "Text"],
Cell[674, 23, 478, 13, 28, "Input"],
Cell[1155, 38, 133, 4, 49, "Text"],
Cell[1291, 44, 385, 9, 28, "Input"],
Cell[1679, 55, 143, 4, 49, "Text"],
Cell[CellGroupData[{
Cell[1847, 63, 239, 3, 28, "Input"],
Cell[2089, 68, 372, 11, 32, "Output"]
}, Open  ]],
Cell[2476, 82, 217, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[2718, 91, 380, 11, 28, "Input"],
Cell[3101, 104, 842, 23, 57, "Output"]
}, Open  ]],
Cell[3958, 130, 215, 6, 49, "Text"],
Cell[4176, 138, 748, 22, 77, "Input"],
Cell[4927, 162, 152, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[5104, 171, 230, 4, 28, InheritFromParent],
Cell[5337, 177, 833, 24, 35, "Output"]
}, Open  ]],
Cell[6185, 204, 166, 5, 49, "Text"],
Cell[CellGroupData[{
Cell[6376, 213, 146, 4, 28, "Input"],
Cell[6525, 219, 966, 26, 47, "Output"]
}, Open  ]],
Cell[7506, 248, 236, 6, 68, "Text"],
Cell[CellGroupData[{
Cell[7767, 258, 147, 4, 28, "Input"],
Cell[7917, 264, 133, 2, 28, "Output"]
}, Open  ]],
Cell[8065, 269, 174, 8, 125, "Text"],
Cell[8242, 279, 640, 17, 60, "Input"],
Cell[CellGroupData[{
Cell[8907, 300, 96, 1, 28, "Input"],
Cell[9006, 303, 597, 16, 34, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9640, 324, 142, 3, 28, "Input"],
Cell[9785, 329, 111, 1, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[9933, 335, 142, 3, 28, "Input"],
Cell[10078, 340, 95, 1, 28, "Output"]
}, Open  ]],
Cell[10188, 344, 202, 4, 30, "Text"]
}
]
*)

(* End of internal cache information *)
